" auto-install vim-plug
if empty(glob('~/.config/nvim/autoload/plug.vim'))
  silent !curl -fLo ~/.config/nvim/autoload/plug.vim --create-dirs
    \ https://raw.githubusercontent.com/junegunn/vim-plug/master/plug.vim
  "autocmd VimEnter * PlugInstall
  "autocmd VimEnter * PlugInstall | source $MYVIMRC
endif

" ale before
let g:ale_completion_enabled = 1
let g:ale_completion_autoimport = 1

call plug#begin('~/.config/nvim/autoload/plugged')
  Plug 'christoomey/vim-tmux-navigator'

  Plug 'mhinz/vim-startify'
  Plug 'dracula/vim'
  Plug 'kyazdani42/nvim-web-devicons'

  Plug 'ourigen/skyline.vim'
  Plug 'romgrk/barbar.nvim'

  Plug 'ojroques/vim-oscyank'
  Plug 'sjl/vitality.vim'

  Plug 'dense-analysis/ale'
  Plug 'tpope/vim-commentary'
  Plug 'prettier/vim-prettier', { 'do': 'yarn install' }
  Plug 'lifepillar/vim-mucomplete'

  Plug 'wellle/context.vim'
  Plug 'Yggdroot/indentLine'

  Plug 'lambdalisue/fern.vim'

  Plug 'nvim-lua/popup.nvim'
  Plug 'nvim-lua/plenary.nvim'
  Plug 'nvim-telescope/telescope.nvim'

  Plug 'lewis6991/gitsigns.nvim'
  Plug 'junegunn/vim-peekaboo'

  Plug 'rmagatti/alternate-toggler'

  Plug 'pangloss/vim-javascript'
  Plug 'vim-ruby/vim-ruby'
  Plug 'mustache/vim-mustache-handlebars'
call plug#end()

" dracula colorscheme
let g:dracula_colorterm = 0 " Set background as transparent
colorscheme dracula

" ale
let b:ale_fixers = ['prettier', 'eslint']
let g:ale_fix_on_save = 1

" prettier
let g:prettier#autoformat_config_present = 1

" javascript
let g:javascript_plugin_jsdoc = 1
let g:javascript_conceal_function = "ƒ"

" mucomplete
set completeopt+=menuone
set completeopt+=noselect
set shortmess+=c   " Shut off completion messages

" indentLine
let g:indentLine_char_list = ['|', '¦', '┆', '┊']

" oscyank
autocmd TextYankPost * if v:event.operator is 'y' && v:event.regname is '+' | OSCYankReg + | endif

" gitsigns
lua << EOF
  require('gitsigns').setup {
    keymaps = {
      noremap = true,
      buffer = true,

      ['n <leader>hn'] = { expr = true, "&diff ? ']c' : '<cmd>lua require\"gitsigns\".next_hunk()<CR>'"},
      ['n <leader>hp'] = { expr = true, "&diff ? '[c' : '<cmd>lua require\"gitsigns\".prev_hunk()<CR>'"},

      ['n <leader>hs'] = '<cmd>lua require"gitsigns".stage_hunk()<CR>',
      ['n <leader>hu'] = '<cmd>lua require"gitsigns".undo_stage_hunk()<CR>',
      ['n <leader>hr'] = '<cmd>lua require"gitsigns".reset_hunk()<CR>',
      ['n <leader>hR'] = '<cmd>lua require"gitsigns".reset_buffer()<CR>',
      ['n <leader>hd'] = '<cmd>lua require"gitsigns".preview_hunk()<CR>',
      ['n <leader>gb'] = '<cmd>lua require"gitsigns".blame_line()<CR>',
    }
  }
EOF
set statusline+=%{get(b:,'gitsigns_status','')}

"" skyline
let g:skyline_encoding = 0
let g:skyline_gitbranch = 1

"" vim-startify
let g:startify_custom_header = [
  \ 'Gaiety | 2021',
  \ '   .::::                              .::           .::                                      .::  ',
  \ ' .:    .:: .::                        .::        .::   .::                                   .::  ',
  \ '.::        .::        .::     .:::: .:.: .:     .::          .::    .::: .:: .::    .::    .:.: .:',
  \ '.::        .: .:    .::  .:: .::      .::       .::        .::  .::  .::  .:  .:: .:   .::   .::  ',
  \ '.::   .::::.::  .::.::    .::  .:::   .::       .::       .::    .:: .::  .:  .::.::::: .::  .::  ',
  \ ' .::    .: .:   .:: .::  .::     .::  .::        .::   .:: .::  .::  .::  .:  .::.:          .::  ',
  \ '  .:::::   .::  .::   .::    .:: .::   .::         .::::     .::    .:::  .:  .::  .::::      .:: ',
  \ '',
  \ 'MAPPING            ACTION',
  \ '━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━',
  \ '<Space>            Leader',
  \ '<Leader>?          List Bindings',
  \ '',
\ ]
let g:startify_change_to_dir = 0
